@@ -628,6 +628,29 @@ class DatabaseBrowser:
             print(f"Deleted {result.rowcount} rows from {table_name} where {column_name} contained the specified error.")
         except Exception as e:
             print(f"Error deleting rows from {table_name}: {e}")
+    def execute_raw_query(self, raw_query, params=None):
+        """
+        Execute a raw SQL query.
+
+        Args:
+            raw_query (str): The raw SQL query string to execute.
+            params (dict, optional): Parameters to pass with the query.
+            print_value (bool, optional): Whether to print the result. Default is False.
+
+        Returns:
+            pd.DataFrame: DataFrame containing the query results or None if no results found.
+        """
+        try:
+            result = self.session.execute(query, params or {})
+            rows = result.fetchall()
+            if rows:
+                df = pd.DataFrame(rows)
+                return df
+            else:
+                print("No results found.")
+        except Exception as e:
+            print(f"Error executing raw query: {e}")
+            return None
     def delete_table(self, table_name: str) -> None:
         """
         Delete the specified table from the database.
